Module classic

Module classic 

JPEG 2000 classic Tier-1 probability and context tables. Shared JPEG 2000 classic Tier-1 probability and context tables.

Structs

ClassicMqState
One JPEG 2000 MQ probability-state transition.

Constants

MQ_QE_VALUES
Primitive MQ probability values for device compilers that cannot lower arrays of structs.
MQ_STATES
MQ values and state transitions from ITU-T T.800 Table C.2.
PACKED_MQ_TRANSITION_VALUES
Packed MQ MPS/LPS transitions and switch flag for device lookup tables.
PACKED_SIGN_CONTEXT_LOOKUP
Packed sign context in the low byte and XOR bit in the high byte.
SIGN_CONTEXT_LOOKUP
Sign-coding context and XOR bit indexed by packed cardinal-neighbor state.
ZERO_CTX_HH_LOOKUP
Zero-coding contexts for HH sub-bands.
ZERO_CTX_HL_LOOKUP
Zero-coding contexts for HL sub-bands.
ZERO_CTX_LL_LH_LOOKUP
Zero-coding contexts for LL and LH sub-bands.