Module dwt

Module dwt 

JPEG 2000 DWT constants. JPEG 2000 discrete wavelet transform constants.

Structs

Dwt53LinearRow
Fixed-capacity sparse row for one linearized 5/3 output sample.
Dwt53LinearTap
One non-zero input contribution to a linearized 5/3 output sample.

Enums

Dwt53Band
Linearized 5/3 output band.

Constants

DWT53_MAX_HIGH_LINEAR_TAPS
Maximum number of input taps contributing to one high-pass 5/3 output.
DWT53_MAX_LINEAR_TAPS
Maximum number of input taps contributing to one linearized 5/3 output.
DWT97_ALPHA_F32
Forward irreversible 9/7 lifting step alpha, rounded for existing CPU/GPU paths.
DWT97_ALPHA_F64
Forward irreversible 9/7 lifting step alpha at f64 precision.
DWT97_BETA_F32
Forward irreversible 9/7 lifting step beta, rounded for existing CPU/GPU paths.
DWT97_BETA_F64
Forward irreversible 9/7 lifting step beta at f64 precision.
DWT97_DELTA_F32
Forward irreversible 9/7 lifting step delta, rounded for existing CPU/GPU paths.
DWT97_DELTA_F64
Forward irreversible 9/7 lifting step delta at f64 precision.
DWT97_GAMMA_F32
Forward irreversible 9/7 lifting step gamma, rounded for existing CPU/GPU paths.
DWT97_GAMMA_F64
Forward irreversible 9/7 lifting step gamma at f64 precision.
DWT97_INV_KAPPA_F32
Inverse irreversible 9/7 scaling factor, computed the same way as existing paths.
DWT97_INV_KAPPA_F64
Inverse irreversible 9/7 scaling factor at f64 precision.
DWT97_KAPPA_F32
Irreversible 9/7 scaling factor, rounded for existing CPU/GPU paths.
DWT97_KAPPA_F64
Irreversible 9/7 scaling factor at f64 precision.
IDWT97_NEG_ALPHA_F32
Inverse 9/7 alpha step used by synthesis paths.
IDWT97_NEG_BETA_F32
Inverse 9/7 beta step used by synthesis paths.
IDWT97_NEG_DELTA_F32
Inverse 9/7 delta step used by synthesis paths.
IDWT97_NEG_GAMMA_F32
Inverse 9/7 gamma step used by synthesis paths.

Functions

linearized_dwt53_row
Derive one conventional linearized 5/3 analysis row in constant work.
max_decomposition_levels
Return the maximum number of DWT decomposition levels supported by an image geometry.